# APISTUBS: Active stubs service, which can interact with tests generator and LLMs

🚀 An MVP realized with the Django framework in a synchronous way

🚧 Rewriting it in a modern way with **async Django** and **FastAPI**.

Additional validation if OpenAPI schema is provided.

## Key Features:
*   **Blackbox Testing:** Treat any microservice as a blackbox and reroute its external requests.
*   **Language-Agnostic:** Works with any microservice, regardless of the programming language or framework used.
*   **AI-Powered Test Generation:** Leverage AI to automatically generate tests, or create them manually.
*   **API and Frontend Testing:** Test your APIs or use it with frontend testing frameworks like Playwright.
